@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 
 from pydantic import BaseModel
 
@@ -24,3 +24,12 @@ class APIHubData(response_models.APIData):
 class ListAPIHubData(BaseModel):
     __root__: list[APIHubData]
 
+
+class APIHubResponse(response_models.APIResponse):
+    data: APIHubData
+
+
+class ListAPIHubResponse(response_models.ListAPIResponse):
+    data: list[Union[APIHubData, dict]]
+
+
